Struct WlDataDeviceManager
pub struct WlDataDeviceManager { /* private fields */ }wayland and Linux only.Expand description
data transfer interface
The wl_data_device_manager is a singleton global object that provides access to inter-client data transfer mechanisms such as copy-and-paste and drag-and-drop. These mechanisms are tied to a wl_seat and this interface lets a client get a wl_data_device corresponding to a wl_seat.
Depending on the version bound, the objects created from the bound wl_data_device_manager object will have different requirements for functioning properly. See wl_data_source.set_actions, wl_data_offer.accept and wl_data_offer.finish for details.
This interface has no events.
Implementations
impl WlDataDeviceManager
impl WlDataDeviceManager
pub fn create_data_source<U, D>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> WlDataSource
pub fn create_data_source<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> WlDataSource
create a new data source
Create a new data source.
pub fn get_data_device<U, D>(
&self,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> WlDataDevice
pub fn get_data_device<U, D>( &self, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> WlDataDevice
create a new data device
Create a new data device for a given seat.
pub fn release(&self)
pub fn release(&self)
destroy wl_data_device_manager
This request destroys the wl_data_device_manager. This has no effect on any other objects.